@@ -1,4 +1,4 @@
-/* GLE - The GTK+ Layout Editor
+/* GLE - The GTK+ Layout Engine
  * Copyright (C) 1998 Tim Janik
  *
  * This library is free software; you can redistribute it and/or
@@ -28,10 +28,34 @@ extern "C" {
 #endif /* __cplusplus */
 
 
+/* --- type macros --- */
+#define	GLE_IS_GARG(garg)	(gtk_type_is_a (((GleGArg*)(garg))->widget_type, gtk_widget_get_type ()) && ((GleGArg*)(garg))->arg_name)
 
 
-void	gle_arg_set_from_string	(GtkArg		*arg,
-				 const gchar	*value_string);
+
+/* --- typedefs --- */
+typedef	struct _GleGArg	GleGArg;
+struct _GleGArg
+{
+  GtkType	 widget_type;
+  const gchar	*arg_name;
+  const GtkArg	*default_arg;
+  GtkArg	 saved_arg;
+  GtkArg	 widget_arg;
+};
+
+
+/* --- prototypes --- */
+GleGArg*	gle_garg_new		(const GtkArg	*dfl_arg);
+void		gle_garg_init		(GleGArg	*garg,
+					 GtkWidget	*widget);
+void		gle_garg_reset		(GleGArg	*garg);
+void		gle_garg_free		(GleGArg*	 garg);
+
+void		gle_arg_reset		(GtkArg		*arg);
+const GtkArg*	gle_arg_get_default	(const gchar	*arg_name);
+void		gle_arg_set_from_string (GtkArg		*arg,
+					 const gchar	*value_string);
 
 
 
