@@ -1,4 +1,4 @@
-/* GLE - The GTK+ Layout Editor
+/* GLE - The GTK+ Layout Engine
  * Copyright (C) 1998 Tim Janik
  *
  * This library is free software; you can redistribute it and/or
@@ -28,22 +28,11 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-/* --- typechecks --- */
-#define GLE_WIDGET_EDITOR(object)    ((GleWidgetEditor*) GTK_WINDOW ((object)))
-#define GLE_IS_WIDGET_EDITOR(object) (GTK_IS_WINDOW ((object)) && gtk_object_get_data ((GtkObject*) (object), gle_key_widget_editor) == (gpointer) (object))
-
-
-/* --- typedefs --- */
-typedef GtkWindow                       GleWidgetEditor;
-
-
-/* --- keys --- */
-extern const gchar      *gle_key_widget_editor;
-
-
 /* --- prototypes -- */
-GtkWidget*	gle_widget_editor_popup    (GtkWidget      	*widget);
-void		gle_widget_editor_reset    (GleWidgetEditor	*widget_editor);
+GtkWidget*	gle_editor_popup	  (GtkWidget      	*widget);
+GtkWidget*	gle_widget_get_editor	  (GtkWidget		*widget);
+void		gle_editor_update_glename (GtkWindow		*editor);
+void		gle_editor_reset	  (GtkWindow		*editor);
 
 
 
